---
name: Bug report
about: Create a report to help us improve.
title: "bug: Describe bug and issue"
labels: bug
assignees: awinml

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment Information (please complete the following information):**
 - OS: [e.g. MacOS, Ubuntu, Windows]
 - Library Version
 - Python Version [e.g. 3.8, 3.9]
 - Haystack Version
 - VoyageAI Version


**Additional context**
Add any other context about the problem here.
